@@ -1,25 +1,21 @@
-#' Log Loss/binary cross entropy
+#' Log Loss/Binary Cross Entropy
 #'
-#' @description Weighted logloss/cross entropy.
-#' @author Michael Mayer, \email{mayermichael79@gmail.com}
-#' @param actual Observed values.
-#' @param predicted Predicted values.
+#' Calculates weighted logloss resp. cross entropy. Equals half of the unit Bernoulli deviance. The smaller, the better.
+#'
+#' @param actual Observed values (0 or 1).
+#' @param predicted Predicted values strictly larger than 0 and smaller than 1.
 #' @param w Optional case weights.
 #' @param ... Further arguments passed to \code{weighted_mean}.
-#'
 #' @return A numeric vector of length one.
-#' 
 #' @export
-#'
 #' @examples
 #' logLoss(c(0, 0, 1, 1), c(0.1, 0.1, 0.9, 0.8))
 #' logLoss(c(1, 0, 0, 1), c(0.1, 0.1, 0.9, 0.8))
 #' logLoss(c(0, 0, 1, 1), c(0.1, 0.1, 0.9, 0.8), w = 1:4)
-#' 
-#' @seealso \code{\link{logLoss}}.
-#' 
+#' @seealso \code{\link{deviance_bernoulli}}.
 logLoss <- function(actual, predicted, w = NULL, ...) {
-  eps <- 1e-15
-  predicted <- pmax(pmin(predicted, 1 - eps), eps)
+  stopifnot(length(actual) == length(predicted),
+            all(actual == 0 | actual == 1),
+            all(predicted > 0 & predicted < 1))
   -weighted_mean(actual * log(predicted) + (1 - actual) * log(1 - predicted), w = w, ...)
-}
\ No newline at end of file
+}
