@@ -1,23 +1,19 @@
-#' Mean-squared error
+#' Mean-Squared Error
+#'
+#' Calculates weighted mean-squared error of prediction. Equals mean unit normal deviance. The smaller, the better.
 #'
-#' @description Weighted mean-squared error of prediction. Equals mean unit normal deviance.
-#' @author Michael Mayer, \email{mayermichael79@gmail.com}
 #' @param actual Observed values.
 #' @param predicted Predicted values.
 #' @param w Optional case weights.
 #' @param ... Further arguments passed to \code{weighted_mean}.
-#'
 #' @return A numeric vector of length one.
-#' 
 #' @export
-#'
 #' @examples
-#' mse(1:10, (1:10)^2)
-#' mse(1:10, (1:10)^2, w = rep(1, 10))
-#' mse(1:10, (1:10)^2, w = 1:10)
-#' 
+#' mse(1:10, c(1:9, 12))
+#' mse(1:10, c(1:9, 12), w = rep(1, 10))
+#' mse(1:10, c(1:9, 12), w = 1:10)
 #' @seealso \code{\link{rmse}, \link{deviance_normal}}.
-#' 
 mse <- function(actual, predicted, w = NULL, ...) {
+  stopifnot(length(actual) == length(predicted))
   weighted_mean((actual - predicted)^2, w = w, ...)
-}
\ No newline at end of file
+}
